@@ -287,7 +287,7 @@ class BaseScheduler(object):
             lock_value = standard_time()
             self.redis_db.process_acquire(lock_name=key, lock_value=lock_value, expire_time=180)
 
-    def check_redis_jobstores(self) -> None:
+    def check_redis_jobstores_jobs(self) -> None:
         '''
         异步检查 redis 中 apscheduler 的任务
         :return:
@@ -316,13 +316,49 @@ class BaseScheduler(object):
                 if stores_job_process_id == belongs_to_process_id:
                     pass
                 else:
-                    if self.redis_job_store.redis.hexists(stores_job_key, job_id):
-                        with self.redis_job_store.redis.pipeline() as pipe:
-                            pipe.hdel(stores_job_key, job_id)
-                            pipe.execute()
-                        with self.redis_job_store.redis.pipeline() as pipe:
-                            pipe.zrem(stores_job_run_times_key, job_id)
-                            pipe.execute()
+                    with self.redis_job_store.redis.pipeline() as pipe:
+                        pipe.hdel(stores_job_key, job_id)
+                        pipe.execute()
+                    with self.redis_job_store.redis.pipeline() as pipe:
+                        pipe.zrem(stores_job_run_times_key, job_id)
+                        pipe.execute()
+
+    def check_redis_jobstores_run_times(self) -> None:
+        '''
+        异步检查 redis 中 apscheduler 的任务
+        :return:
+        '''
+        job_process_dict = {}
+        for all_key in self.redis_db.get_all_task():
+            all_value = self.redis_db.from_key_get_value(all_key)
+            if all_value is None:
+                continue
+            process_node_id = all_value["process_node_id"]
+            job_id = all_value["job_id"]
+            job_process_dict[job_id] = process_node_id
+        if len(job_process_dict) == 0:
+            return
+        stores_job_run_time_task = self.redis_db.get_stores_job_run_time_task()
+        for stores_job_run_times_key in stores_job_run_time_task:
+            stores_job_key = stores_job_run_times_key.replace('run_times', 'jobs')
+            stores_job_process_id = stores_job_run_times_key.replace('apscheduler:run_times', 'node')
+            apscheduler_run_time_byte_list = self.redis_job_store.redis.zrange(stores_job_run_times_key, 0, 4821384687,
+                                                                               withscores=True)
+            for job_id_byte, run_time__byte_timestamp in apscheduler_run_time_byte_list:
+                job_id = job_id_byte.decode('utf-8')
+                try:
+                    belongs_to_process_id = job_process_dict[job_id]
+                except KeyError:
+                    continue
+                if stores_job_process_id == belongs_to_process_id:
+                    pass
+                else:
+                    with self.redis_job_store.redis.pipeline() as pipe:
+                        pipe.hdel(stores_job_key, job_id)
+                        pipe.execute()
+                    with self.redis_job_store.redis.pipeline() as pipe:
+                        pipe.zrem(stores_job_run_times_key, job_id)
+                        pipe.execute()
 
     def check_lost_tasks(self) -> None:
         redis_apscheduler_run_time_job_id_set = set()
