@@ -92,15 +92,19 @@ class TaskScheduler(object):
         def check_process() -> None:
             self.register_base_scheduler.check_process()
 
-        @repeat_every(seconds=8)
+        @repeat_every(seconds=20)
         def check_scheduler_run() -> None:
             self.register_base_scheduler.run()
 
-        @repeat_every(seconds=10)
-        def check_redis_jobstores() -> None:
-            self.register_base_scheduler.check_redis_jobstores()
+        @repeat_every(seconds=20)
+        def check_redis_jobstores_jobs() -> None:
+            self.register_base_scheduler.check_redis_jobstores_jobs()
 
-        @repeat_every(seconds=10)
+        @repeat_every(seconds=30)
+        def check_redis_jobstores_run_times() -> None:
+            self.register_base_scheduler.check_redis_jobstores_run_times()
+
+        @repeat_every(seconds=25)
         def check_lost_tasks() -> None:
             self.register_base_scheduler.check_lost_tasks()
 
@@ -112,7 +116,8 @@ class TaskScheduler(object):
 
         self.app.on_event("startup")(check_process)
         self.app.on_event("startup")(check_scheduler_run)
-        self.app.on_event("startup")(check_redis_jobstores)
+        self.app.on_event("startup")(check_redis_jobstores_jobs)
+        self.app.on_event("startup")(check_redis_jobstores_run_times)
         self.app.on_event("startup")(check_lost_tasks)
         self.app.on_event("startup")(scheduler_start)
         self.app.on_event("shutdown")(scheduler_shutdown)
